@@ -19,38 +19,41 @@
 #define KNEWSTUFF3_ENTRYDETAILSDIALOG_P_H
 
 #include <QtCore/QObject>
-#include "core/entryinternal_p.h"
+#include "core/entryinternal.h"
 
 #include "ui_downloadwidget.h"
 
 class QListWidgetItem;
 
-namespace KNS3
+namespace KNSCore
 {
 class Engine;
+}
 
+namespace KNS3
+{
 class EntryDetails : public QObject
 {
     Q_OBJECT
 
 public:
-    EntryDetails(Engine *engine, Ui::DownloadWidget *widget);
+    EntryDetails(KNSCore::Engine *engine, Ui::DownloadWidget *widget);
     ~EntryDetails();
 
 public Q_SLOTS:
-    void setEntry(const KNS3::EntryInternal &entry);
+    void setEntry(const KNSCore::EntryInternal &entry);
 
 private Q_SLOTS:
-    void slotEntryPreviewLoaded(const KNS3::EntryInternal &entry, KNS3::EntryInternal::PreviewType type);
+    void slotEntryPreviewLoaded(const KNSCore::EntryInternal &entry, KNSCore::EntryInternal::PreviewType type);
     void install();
     void uninstall();
 
     void ratingChanged(uint rating);
     void becomeFan();
     // more details loaded
-    void entryChanged(const KNS3::EntryInternal &entry);
+    void entryChanged(const KNSCore::EntryInternal &entry);
     // installed/updateable etc
-    void entryStatusChanged(const KNS3::EntryInternal &entry);
+    void entryStatusChanged(const KNSCore::EntryInternal &entry);
     void updateButtons();
 
     void preview1Selected();
@@ -61,9 +64,9 @@ private:
     void init();
     void previewSelected(int current);
 
-    Engine *m_engine;
+    KNSCore::Engine *m_engine;
     Ui::DownloadWidget *ui;
-    EntryInternal m_entry;
+    KNSCore::EntryInternal m_entry;
     QImage m_currentPreview;
     QListWidgetItem *m_previewItem1;
     QListWidgetItem *m_previewItem2;
